RTTIClassHierarchyDescriptor

Struct RTTIClassHierarchyDescriptor 

#[repr(C)]
pub struct RTTIClassHierarchyDescriptor { pub signature: u32, pub attributes: u32, pub num_base_classes: u32, pub base_class_array: Ptr<[Ptr<RTTIBaseClassDescriptor>]>, }
Class Hierarchy Descriptor.

Describes the inheritance hierarchy of the class, it is shared by all COLs.

Fields

signature: u32

Always zero?

attributes: u32

Bit 0 set = multiple inheritance, bit 1 set = virtual inheritance.

num_base_classes: u32

Number of classes in base_class_array.

base_class_array: Ptr<[Ptr<RTTIBaseClassDescriptor>]>

Pointer to an array of pointers to base class descriptors.