#[repr(C)]pub struct RTTICompleteObjectLocator {
pub signature: u32,
pub offset: u32,
pub cd_offset: u32,
pub type_descriptor: Ptr<TypeDescriptor>,
pub class_descriptor: Ptr<RTTIClassHierarchyDescriptor>,
}Expand description
Complete Object Locator.
MSVC compiler puts a pointer to this structure just before the vftable. The structure is called so because it lets you find the location to the complete object from a specific vftable pointer.
Every vftable has its own Complete Object Locator.
Fields
signature: u32Always zero?
offset: u32Offset of this vtable in the complete class.
cd_offset: u32Constructor displacement offset.
type_descriptor: Ptr<TypeDescriptor>Pointer to the type descriptor of the complete class.
class_descriptor: Ptr<RTTIClassHierarchyDescriptor>Pointer to the class hierarchy descriptor.